@@ -168,6 +168,8 @@ def pack_model():
         os.system('mkdir out/{}'.format(name))
         os.system('cp ./application.yml ./out/{}/'.format(name))
         os.system('cp ./requirements.txt ./out/{}/'.format(name))
+        if os.path.exists('docs'):
+            os.system('cp -r ./docs ./out/{}/'.format(name))
 
     if build_so:
         so_builder = SoBuilder('core')
